#[repr(C)]pub struct DeviceGetHardwareIdResponse {
pub response: Uint32,
}Expand description
The wire type corresponding to DeviceGetHardwareIdResponse.
Fields
response: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetHardwareIdResponse
impl Clone for DeviceGetHardwareIdResponse
Sourcefn clone(&self) -> DeviceGetHardwareIdResponse
fn clone(&self) -> DeviceGetHardwareIdResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetHardwareIdResponse
impl Constrained for DeviceGetHardwareIdResponse
Sourceimpl Debug for DeviceGetHardwareIdResponse
impl Debug for DeviceGetHardwareIdResponse
Sourceimpl<___D> Decode<___D> for DeviceGetHardwareIdResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetHardwareIdResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetHardwareIdResponse, ___E> for &'a DeviceGetHardwareIdResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetHardwareIdResponse, ___E> for &'a DeviceGetHardwareIdResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetHardwareIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetHardwareIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetHardwareIdResponse, ___E> for DeviceGetHardwareIdResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetHardwareIdResponse, ___E> for DeviceGetHardwareIdResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetHardwareIdResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetHardwareIdResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetHardwareIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetHardwareIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetHardwareIdResponse, ___E> for DeviceGetHardwareIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetHardwareIdResponse, ___E> for DeviceGetHardwareIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetHardwareIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetHardwareIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetHardwareIdResponse> for DeviceGetHardwareIdResponse
impl FromWire<DeviceGetHardwareIdResponse> for DeviceGetHardwareIdResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetHardwareIdResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetHardwareIdResponse, Self>
Sourcefn from_wire(wire: DeviceGetHardwareIdResponse) -> Self
fn from_wire(wire: DeviceGetHardwareIdResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetHardwareIdResponse> for DeviceGetHardwareIdResponse
impl FromWireRef<DeviceGetHardwareIdResponse> for DeviceGetHardwareIdResponse
Sourcefn from_wire_ref(wire: &DeviceGetHardwareIdResponse) -> Self
fn from_wire_ref(wire: &DeviceGetHardwareIdResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetHardwareIdResponse
impl IntoNatural for DeviceGetHardwareIdResponse
Sourcetype Natural = DeviceGetHardwareIdResponse
type Natural = DeviceGetHardwareIdResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetHardwareIdResponse
impl Wire for DeviceGetHardwareIdResponse
Sourcetype Narrowed<'de> = DeviceGetHardwareIdResponse
type Narrowed<'de> = DeviceGetHardwareIdResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.